@@ -1,8 +1,8 @@
 # --
 # Kernel/Config/Defaults.pm - Default Config file for OTRS kernel
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Defaults.pm,v 1.377 2011/01/06 09:54:05 mn Exp $
+# $Id: Defaults.pm,v 1.377.2.9 2012/02/23 11:21:00 des Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -24,8 +24,12 @@ package Kernel::Config::Defaults;
 use strict;
 use warnings;
 
+# Perl 5.8.6 is the required minimum version to use OTRS.
+# Do not use require VERSION as it leaks variables.
+use 5.008_006;
+
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.377 $) [1];
+$VERSION = qw($Revision: 1.377.2.9 $) [1];
 
 # prepend '../Custom', '../Kernel/cpan-lib' and '../' to the module search path @INC
 use File::Basename;
@@ -171,9 +175,12 @@ sub LoadDefaults {
         fa      => 'Persian (&#x0641;&#x0627;&#x0631;&#x0633;&#x0649;)',
         fr      => 'Fran&ccedil;ais',
         fi      => 'Suomi',
+        hi      => 'Hindi',
+        hr      => 'Hrvatski',
         hu      => 'Magyar',
         it      => 'Italiano',
         ja      => 'Japanese (&#x65e5;&#x672c;&#x8a9e)',
+        lt      => 'Lietuvi&#371; kalba',
         lv      => 'Latvijas',
         nl      => 'Nederlands',
         nb_NO   => 'Norsk bokm&aring;l',
@@ -337,6 +344,11 @@ sub LoadDefaults {
     # This is the auth. module againt the otrs db
     $Self->{AuthModule} = 'Kernel::System::Auth::DB';
 
+    # defines AuthSyncBackend (AuthSyncModule) for AuthModule
+    # if this key exists and is empty, there won't be a sync.
+    # example values: AuthSyncBackend, AuthSyncBackend2
+#    $Self->{'AuthModule::UseSyncBackend'} = '';
+
     # password crypt type (sha2|sha1|md5|crypt|plain)
 #    $Self->{'AuthModule::DB::CryptType'} = 'md5';
 
@@ -1385,7 +1397,7 @@ Your OTRS Notification Master
             [ 'UserPassword',   'Password',   'pw',         0, 0, 'var', '', 0 ],
             [ 'UserEmail',      'Email',      'email',      1, 1, 'var', '', 0 ],
 
-#            [ 'UserEmail',      'Email', 'email',           1, 1, 'var', '$Env{"CGIHandle"}?Action=AgentTicketCompose&ResponseID=1&TicketID=$Data{"TicketID"}&ArticleID=$Data{"ArticleID"}', 0 ],
+#            [ 'UserEmail',      'Email', 'email',           1, 1, 'var', '$Env{"CGIHandle"}?Action=AgentTicketCompose&ResponseID=1&TicketID=$Data{"TicketID"}&ArticleID=$Data{"ArticleID"}', 0, 'OTRSPopup_TicketAction' ],
             [ 'UserCustomerID', 'CustomerID', 'customer_id', 0, 1, 'var', '', 0 ],
 
 #            [ 'UserCustomerIDs', 'CustomerIDs', 'customer_ids', 1, 0, 'var', '', 0 ],
@@ -1759,7 +1771,6 @@ Your OTRS Notification Master
                 'Yemen'                                => 'Yemen',
                 'Zambia'                               => 'Zambia',
                 'Zimbabwe'                             => 'Zimbabwe',
-                'Lettland'                             => 'Lettland',
             },
         },
     };
@@ -2015,20 +2026,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check required perl version
-    if ( !eval { require 5.008006 } ) {
-
-        my $RequiredPerl = 'v5.8.6';
-        my $CurrentPerl  = $^V;
-
-        my $Message = "\nERROR:\n"
-            . "Currently you are using Perl $CurrentPerl, but Perl $RequiredPerl is required for technical reasons!\n"
-            . "In order to use this version of OTRS, you need to have Perl $RequiredPerl installed.\n"
-            . "Otherwise you can also use an older version of OTRS.\n\n";
-
-        die $Message;
-    }
-
     # 0=off; 1=log if there exists no entry; 2=log all;
     $Self->{Debug} = 0;
 
@@ -2226,6 +2223,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.377 $ $Date: 2011/01/06 09:54:05 $
+$Revision: 1.377.2.9 $ $Date: 2012/02/23 11:21:00 $
 
 =cut
